@@ -15,8 +15,10 @@ from .changelog import markdown_changelog
 from .dist import build_dists, remove_dists, should_build, should_remove_dist
 from .history import (
     evaluate_version_bump,
+    get_current_release_version,
     get_current_version,
     get_new_version,
+    get_previous_release_version,
     get_previous_version,
     set_new_version,
 )
@@ -98,7 +100,11 @@ def print_version(*, current=False, force_level=None, prerelease=False, **kwargs
     Print the current or new version to standard output.
     """
     try:
-        current_version = get_current_version(prerelease)
+        current_version = get_current_version()
+        current_release_version = get_current_release_version()
+        logger.info(
+            f"Current version: {current_version}, Current release version: {current_release_version}"
+        )
     except GitError as e:
         print(str(e), file=sys.stderr)
         return False
@@ -108,7 +114,9 @@ def print_version(*, current=False, force_level=None, prerelease=False, **kwargs
 
     # Find what the new version number should be
     level_bump = evaluate_version_bump(current_version, force_level)
-    new_version = get_new_version(current_version, level_bump, prerelease)
+    new_version = get_new_version(
+        current_version, current_release_version, level_bump, prerelease
+    )
     if should_bump_version(current_version=current_version, new_version=new_version):
         print(new_version, end="")
         return True
@@ -130,14 +138,19 @@ def version(*, retry=False, noop=False, force_level=None, prerelease=False, **kw
 
     # Get the current version number
     try:
-        current_version = get_current_version(prerelease)
-        logger.info(f"Current version: {current_version}")
+        current_version = get_current_version()
+        current_release_version = get_current_release_version()
+        logger.info(
+            f"Current version: {current_version}, Current release version: {current_release_version}"
+        )
     except GitError as e:
         logger.error(str(e))
         return False
     # Find what the new version number should be
-    level_bump = evaluate_version_bump(current_version, force_level)
-    new_version = get_new_version(current_version, level_bump, prerelease)
+    level_bump = evaluate_version_bump(current_release_version, force_level)
+    new_version = get_new_version(
+        current_version, current_release_version, level_bump, prerelease
+    )
 
     if not should_bump_version(
         current_version=current_version, new_version=new_version, retry=retry, noop=noop
@@ -183,6 +196,14 @@ def bump_version(new_version, level_bump):
 
     Edit in the source code, commit and create a git tag.
     """
+    logger.info(f"Bumping with a {level_bump} version to {new_version}")
+    if config.get("version_source") == "tag_only":
+        tag_new_version(new_version)
+
+        # we are done, no need for file changes if we are using
+        # tags as version source
+        return
+
     set_new_version(new_version)
     if config.get(
         "commit_version_number",
@@ -192,8 +213,6 @@ def bump_version(new_version, level_bump):
     if config.get("version_source") == "tag" or config.get("tag_commit"):
         tag_new_version(new_version)
 
-    logger.info(f"Bumping with a {level_bump} version to {new_version}")
-
 
 def changelog(*, unreleased=False, noop=False, post=False, prerelease=False, **kwargs):
     """
@@ -201,7 +220,7 @@ def changelog(*, unreleased=False, noop=False, post=False, prerelease=False, **k
 
     :raises ImproperConfigurationError: if there is no current version
     """
-    current_version = get_current_version(prerelease)
+    current_version = get_current_version()
     if current_version is None:
         raise ImproperConfigurationError(
             "Unable to get the current version. "
@@ -239,7 +258,11 @@ def publish(
     retry: bool = False, noop: bool = False, prerelease: bool = False, **kwargs
 ):
     """Run the version task, then push to git and upload to an artifact repository / GitHub Releases."""
-    current_version = get_current_version(prerelease)
+    current_version = get_current_version()
+    current_release_version = get_current_release_version()
+    logger.info(
+        f"Current version: {current_version}, Current release version: {current_release_version}"
+    )
 
     verbose = logger.isEnabledFor(logging.DEBUG)
     if retry:
@@ -248,11 +271,13 @@ def publish(
         # "current" version will be the previous version.
         level_bump = None
         new_version = current_version
-        current_version = get_previous_version(current_version)
+        current_version = get_previous_release_version(current_version)
     else:
         # Calculate the new version
         level_bump = evaluate_version_bump(current_version, kwargs.get("force_level"))
-        new_version = get_new_version(current_version, level_bump, prerelease)
+        new_version = get_new_version(
+            current_version, current_release_version, level_bump, prerelease
+        )
 
     owner, name = get_repository_owner_and_name()
 
